qpimage documentation
=====================

Qpimage is a Python3 library that provides a convenient interface
to many common functionalities that are used in quantitative
phase imaging. This is the documentaion of qpimage version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   sec_introduction
   sec_getting_started
   sec_code_reference
   sec_bibliography


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
